# this is new spider framework gerridae

> 学习之作, 参考[ruia](https://github.com/howie6879/ruia)

## v0.1.0目标设计

> 2019-07-06

- [x] 完成基本`spider`, `item`设定
- [ ] 满足`comet`基本爬取设定
- [x] 支持`css selector`方式


